@@ -5,6 +5,7 @@ import aiohttp
 from ...config import Config
 from .melon import resolve as melon_resolve
 from .spotify import resolve as spotify_resolve
+from .vibe import resolve as vibe_resolve
 
 
 async def resolve(
@@ -14,5 +15,7 @@ async def resolve(
         query = await melon_resolve(query, connector)
     if "spotify" in Config.ENABLED_EXT_RESOLVER:
         query = await spotify_resolve(query)
+    if "vibe" in Config.ENABLED_EXT_RESOLVER:
+        query = await vibe_resolve(query, connector)
 
     return query
