@@ -5,7 +5,7 @@ import aiohttp
 from bs4 import BeautifulSoup
 
 MELON_REGEX = re.compile(
-    r"(?:https?:\/\/)?(?:www\.)?melon.com\/album\/detail.htm\?albumId=([0-9]+)"
+    r"(?:https?:\/\/)?(?:www\.)?melon.com/album/detail.htm\?albumId=([0-9]+)"
 )
 
 
@@ -13,9 +13,10 @@ async def get_album(url: str, connector: aiohttp.TCPConnector = None) -> list:
     async with aiohttp.ClientSession(
         headers={
             "User-Agent": "Mozilla/5.0 (Windows NT 6.3; Trident/7.0; rv:11.0) like Gecko"
-        }
+        },
+        connector=connector,
     ) as session:
-        async with session.get(url, connector=connector) as resp:
+        async with session.get(url) as resp:
             Body = await resp.text()
 
     soup = BeautifulSoup(Body, "html.parser")
