@@ -45,8 +45,9 @@ class keepAliver(threading.Thread):
                     Runner.result()
                 except:
                     pass
-                finally:
-                    return self.stop()
+                
+                self.stop()
+                return
 
             payload: Dict[str, int] = {
                 "op": VoicePayload.HEARTBEAT,
@@ -108,18 +109,23 @@ class VoiceSocket:
         self.threadId = threading.get_ident()
 
     def __del__(self) -> None:
-        self.loop.create_task(self.close())
+        self.loop.call_soon_threadsafe(lambda: self.loop.create_task(self.close()))
 
     @classmethod
     async def connect(cls, client, resume=False):
         session = aiohttp.ClientSession()
-        socket = await session.ws_connect(
-            f"wss://{client.endpoint}/?v=4",
-            max_msg_size=0,
-            timeout=30.0,
-            autoclose=False,
-            compress=15,
-        )
+
+        try:
+            socket = await session.ws_connect(
+                f"wss://{client.endpoint}/?v=4",
+                max_msg_size=0,
+                timeout=30.0,
+                autoclose=False,
+                compress=15,
+            )
+        except Exception as e:
+            await session.close()
+            raise e
 
         ws = cls(client, session, socket)
 
