@@ -132,21 +132,6 @@ class WebsocketPayloads:
 
         await self.sendJson(payload)
 
-    @need_manager
-    async def setGapless(self, Data: dict) -> None:
-        VoiceClient = self.ClientManager.getVC(Data["guild_id"])
-        if not VoiceClient:
-            raise NotConnected
-
-        VoiceClient.gapless = Data["gapless"]
-
-        payload = {
-            "op": "setGapless",
-            "d": {"guild_id": Data["guild_id"], "gapless": VoiceClient.gapless},
-        }
-
-        await self.sendJson(payload)
-
     @need_manager
     async def setAutoplay(self, Data: dict) -> None:
         VoiceClient = self.ClientManager.getVC(Data["guild_id"])
@@ -294,7 +279,6 @@ class WebsocketPayloads:
                     "autoplay": VoiceClient.autoplay,
                     "volume": VoiceClient.volume,
                     "crossfade": VoiceClient.crossfade,
-                    "gapless": VoiceClient.gapless,
                     "filter": VoiceClient.filter,
                 },
             },
@@ -368,13 +352,18 @@ class WebsocketPayloads:
             Element = Subtitle.seek(current.position)
 
             if Element and Element["markdown"] and Element["markdown"] != Now:
-                Previous = Now
+                if not Element["markdown"].startswith(Now) and not Element[
+                    "markdown"
+                ].endswith(Now):
+                    Previous = Now
                 Now = Element["markdown"]
 
                 NextElements = [
                     NextElement["markdown"]
                     for NextElement in Elements[Elements.index(Element) + 1 :]
                     if NextElement["markdown"] != Now
+                    if not NextElement["markdown"].startswith(Now)
+                    and not NextElement["markdown"].endswith(Now)
                 ]
 
                 Next = NextElements[0] if NextElements else None
