@@ -6,6 +6,7 @@ from typing import Coroutine
 from sanic import Blueprint
 from sanic.websocket import ConnectionClosed
 
+from .. import __version__
 from ..config import Config
 from ..manager import ClientManager
 from .payloads import WebsocketPayloads
@@ -147,7 +148,6 @@ class WebsocketHandler:
         self.ClientManager.dispatcher.onAny(self.manager_event)
 
     async def manager_event(self, guild_id: int, **kwargs) -> None:
-        kwargs = {key: value for key, value in kwargs.items()}
         Event = kwargs.pop("event")
 
         payload = {"op": Event, "d": {"guild_id": guild_id}}
@@ -158,7 +158,10 @@ class WebsocketHandler:
     async def hello(self) -> None:
         payload = {
             "op": "HELLO",
-            "d": {"heartbeat_interval": Config.HANDSHAKE_INTERVAL},
+            "d": {
+                "version": __version__,
+                "heartbeat_interval": Config.HANDSHAKE_INTERVAL,
+            },
         }
 
         await self.sendJson(payload)
